You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2008/05/20 20:52:29 UTC

svn commit: r658390 [27/32] - in /tapestry/tapestry5/branches/hlship-20080520: ./ quickstart/src/main/resources/META-INF/ quickstart/src/main/resources/archetype-resources/src/main/java/pages/ quickstart/src/main/resources/archetype-resources/src/main/...

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/ConcurrentBarrier.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/ConcurrentBarrier.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/ConcurrentBarrier.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/ConcurrentBarrier.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.ReadWriteLock;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Defense.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Defense.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Defense.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Defense.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
 /**
  * Static utility methods for defensive programming.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/DependencyNode.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/DependencyNode.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/GenericsUtils.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/GenericsUtils.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
 import java.lang.reflect.Method;
 import java.lang.reflect.ParameterizedType;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/IdAllocator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/IdAllocator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/IdAllocator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/IdAllocator.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
 import java.util.HashMap;
 import java.util.IdentityHashMap;
@@ -182,4 +182,4 @@
     {
         generatorMap.clear();
     }
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/InheritanceSearch.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/InheritanceSearch.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/InheritanceSearch.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/InheritanceSearch.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
-import org.apache.tapestry.ioc.services.ClassFabUtils;
+import org.apache.tapestry5.ioc.services.ClassFabUtils;
 
 import java.util.Iterator;
 import java.util.LinkedList;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/InternalUtils.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/InternalUtils.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Invokable.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Invokable.java Tue May 20 11:51:35 2008
@@ -1,26 +1,25 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.internal.util;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.internal.util;
 
 
 /**
- * Similiar to {@link Runnable} execpt that it returns a value. Used by {@link ConcurrentBarrier} to
- * identify the block of code to execute with read/write lock protection.
+ * Similiar to {@link Runnable} execpt that it returns a value. Used by {@link ConcurrentBarrier} to identify the block
+ * of code to execute with read/write lock protection.
  *
- * @param <T>
- * the return value type
+ * @param <T> the return value type
  */
 public interface Invokable<T>
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/LocalizedNameGenerator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/LocalizedNameGenerator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/LocalizedNameGenerator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/LocalizedNameGenerator.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
 import java.util.Iterator;
 import java.util.Locale;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/LocationImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/LocationImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/MessageFormatterImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/MessageFormatterImpl.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
-import org.apache.tapestry.ioc.MessageFormatter;
+import org.apache.tapestry5.ioc.MessageFormatter;
 
 import java.util.Locale;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/MessagesImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/MessagesImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/OneShotLock.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/OneShotLock.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
 /**
  * Logic for handling one shot semantics for classes; classes that include a method (or methods) that "locks down" the

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Orderer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Orderer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Orderer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Orderer.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
-import org.apache.tapestry.ioc.IdMatcher;
-import org.apache.tapestry.ioc.Orderable;
-import org.apache.tapestry.ioc.internal.IdMatcherImpl;
-import org.apache.tapestry.ioc.internal.OrIdMatcher;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newList;
+import org.apache.tapestry5.ioc.IdMatcher;
+import org.apache.tapestry5.ioc.Orderable;
+import org.apache.tapestry5.ioc.internal.IdMatcherImpl;
+import org.apache.tapestry5.ioc.internal.OrIdMatcher;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newList;
 import org.slf4j.Logger;
 
 import java.util.Collection;
@@ -239,4 +239,4 @@
 
         return matchers.size() == 1 ? matchers.get(0) : new OrIdMatcher(matchers);
     }
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/TapestryException.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/TapestryException.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/TapestryException.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/TapestryException.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
-import org.apache.tapestry.ioc.Locatable;
-import org.apache.tapestry.ioc.Location;
+import org.apache.tapestry5.ioc.Locatable;
+import org.apache.tapestry5.ioc.Location;
 
 /**
  * Exception class used as a replacement for {@link java.lang.RuntimeException} when the exception is related to a

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/UtilMessages.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/UtilMessages.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/UtilMessages.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/UtilMessages.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
-import org.apache.tapestry.ioc.Messages;
+import org.apache.tapestry5.ioc.Messages;
 
 class UtilMessages
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/idToDependencyNode.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/idToDependencyNode.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/idToDependencyNode.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/idToDependencyNode.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
-import org.apache.tapestry.ioc.IdMatcher;
-import org.apache.tapestry.ioc.Orderable;
-import org.apache.tapestry.ioc.internal.IdMatcherImpl;
-import org.apache.tapestry.ioc.internal.OrIdMatcher;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newList;
+import org.apache.tapestry5.ioc.IdMatcher;
+import org.apache.tapestry5.ioc.Orderable;
+import org.apache.tapestry5.ioc.internal.IdMatcherImpl;
+import org.apache.tapestry5.ioc.internal.OrIdMatcher;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newList;
 import org.slf4j.Logger;
 
 import java.util.Collection;
@@ -106,7 +106,7 @@
      * @param id          unique, qualified id for the target
      * @param target      the object to be ordered (or null as a placeholder)
      * @param constraints optional, variable constraints
-     * @see #add(org.apache.tapestry.ioc.Orderable)
+     * @see #add(org.apache.tapestry5.ioc.Orderable)
      */
 
     public void add(String id, T target, String... constraints)
@@ -239,4 +239,4 @@
 
         return matchers.size() == 1 ? matchers.get(0) : new OrIdMatcher(matchers);
     }
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ApplicationDefaults.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ApplicationDefaults.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ApplicationDefaults.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ApplicationDefaults.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -22,13 +22,13 @@
 import java.lang.annotation.Target;
 
 /**
- * Used to disambiguate which version of {@link SymbolProvider} is being referenced. Contributions
- * to the ApplicationDefaults symbol source are overridden by JVM System properties.
+ * Used to disambiguate which version of {@link SymbolProvider} is being referenced. Contributions to the
+ * ApplicationDefaults symbol source are overridden by JVM System properties.
  *
  * @see FactoryDefaults
  */
 @Target(
-        {PARAMETER, FIELD})
+        { PARAMETER, FIELD })
 @Retention(RUNTIME)
 @Documented
 public @interface ApplicationDefaults

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/AspectDecorator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/AspectDecorator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Builtin.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Builtin.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -22,16 +22,15 @@
 import java.lang.annotation.Target;
 
 /**
- * Marks services provided by this module that may need to be unambiguously referenced.
- * Injecting with this marker annotation and the correct type ensure that the version defined in
- * this module is used, even if another module provides a service with the same service
- * interface.
+ * Marks services provided by this module that may need to be unambiguously referenced. Injecting with this marker
+ * annotation and the correct type ensure that the version defined in this module is used, even if another module
+ * provides a service with the same service interface.
  */
 @Target(
-        {PARAMETER, FIELD})
+        { PARAMETER, FIELD })
 @Retention(RUNTIME)
 @Documented
 public @interface Builtin
 {
 
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ChainBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ChainBuilder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ChainBuilder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ChainBuilder.java Tue May 20 11:51:35 2008
@@ -1,43 +1,41 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.services;
 
 import java.util.List;
 
 /**
- * A service which can assemble an implementation based on a command interface, and an ordered list
- * of objects implementing that interface (the "commands"). This is an implementation of the Gang of
- * Four Chain Of Command pattern.
+ * A service which can assemble an implementation based on a command interface, and an ordered list of objects
+ * implementing that interface (the "commands"). This is an implementation of the Gang of Four Chain Of Command
+ * pattern.
  * <p/>
- * For each method in the interface, the chain implementation will call the corresponding method on
- * each command object in turn (with the order defined by the list). If any of the command objects
- * return true, then the chain of command stops and the initial method invocation returns true.
- * Otherwise, the chain of command continues to the next command (and will return false if none of
- * the commands returns true).
+ * For each method in the interface, the chain implementation will call the corresponding method on each command object
+ * in turn (with the order defined by the list). If any of the command objects return true, then the chain of command
+ * stops and the initial method invocation returns true. Otherwise, the chain of command continues to the next command
+ * (and will return false if none of the commands returns true).
  * <p/>
- * For methods whose return type is not boolean, the chain stops with the first non-null (for object
- * types), or non-zero (for numeric types). The chain returns the value that was returned by the
- * command. If the method return type is void, all commands will be invoked.
+ * For methods whose return type is not boolean, the chain stops with the first non-null (for object types), or non-zero
+ * (for numeric types). The chain returns the value that was returned by the command. If the method return type is void,
+ * all commands will be invoked.
  * <p/>
  * Method invocations will also be terminated if an exception is thrown.
  */
 public interface ChainBuilder
 {
     /**
-     * Creates a chain instance from a command interface and a list of commands (implementing the
-     * interface).
+     * Creates a chain instance from a command interface and a list of commands (implementing the interface).
      */
     <T> T build(Class<T> commandInterface, List<T> commands);
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFab.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFab.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFab.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFab.java Tue May 20 11:51:35 2008
@@ -12,41 +12,33 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 /**
  * Used when fabricating a new class. Represents a wrapper around the Javassist library.
  * <p/>
- * The core concept of Javassist is how method bodies (as well as constructor bodies, etc.) are
- * specified ... as a very Java-like scripting language. Details are available at the <a
- * href="http://jboss.org/products/javassist">Javassist home page</a>.
+ * The core concept of Javassist is how method bodies (as well as constructor bodies, etc.) are specified ... as a very
+ * Java-like scripting language. Details are available at the <a href="http://jboss.org/products/javassist">Javassist
+ * home page</a>.
  * <p/>
- * Method bodies look largely like Java. References to java classes must be fully qualified. Several
- * special variables are used:
- * <ul>
- * <li><code>$0</code> first parameter, equivalent to <code>this</code> in Java code (and can't
- * be used when creating a static method)
- * <li><code>$1, $2, ...</code> actual parameters to the method
- * <li><code>$args</code> all the parameters as an <code>Object[]</code>
- * <li><code>$r</code> the return type of the method, typically used as
- * <code>return ($r) ...</code>. <code>$r</code> is valid with method that return
- * <code>void</code>. This also handles conversions between wrapper types and primitive types.
- * <li><code>$w</code> conversion from primitive type to wrapper type, used as
- * <code>($w) foo()</code> where <code>foo()</code> returns a primitive type and a wrapper type
- * is needed
- * <li>
- * </ul>
+ * Method bodies look largely like Java. References to java classes must be fully qualified. Several special variables
+ * are used: <ul> <li><code>$0</code> first parameter, equivalent to <code>this</code> in Java code (and can't be used
+ * when creating a static method) <li><code>$1, $2, ...</code> actual parameters to the method <li><code>$args</code>
+ * all the parameters as an <code>Object[]</code> <li><code>$r</code> the return type of the method, typically used as
+ * <code>return ($r) ...</code>. <code>$r</code> is valid with method that return <code>void</code>. This also handles
+ * conversions between wrapper types and primitive types. <li><code>$w</code> conversion from primitive type to wrapper
+ * type, used as <code>($w) foo()</code> where <code>foo()</code> returns a primitive type and a wrapper type is needed
+ * <li> </ul>
  * <p/>
  * ClassFab instances are not thread safe.
  * <p/>
- * ClassFab instances are created by a {@link org.apache.tapestry.ioc.services.ClassFactory}.
+ * ClassFab instances are created by a {@link org.apache.tapestry5.ioc.services.ClassFactory}.
  */
 public interface ClassFab
 {
     /**
-     * Adds the specified interface as an interface implemented by this class. It is not an error to
-     * invoke this method multiple times with the same interface class (and the interface is only
-     * added once).
+     * Adds the specified interface as an interface implemented by this class. It is not an error to invoke this method
+     * multiple times with the same interface class (and the interface is only added once).
      */
     void addInterface(Class interfaceClass);
 
@@ -67,8 +59,8 @@
      * @param signature defines the name, return type, parameters and exceptions thrown
      * @param body      The body of the method.
      * @return a method fabricator, used to add catch handlers.
-     * @throws RuntimeException if a method with that signature has already been added, or if there is a
-     *                          Javassist compilation error
+     * @throws RuntimeException if a method with that signature has already been added, or if there is a Javassist
+     *                          compilation error
      */
     void addMethod(int modifiers, MethodSignature signature, String body);
 
@@ -87,29 +79,26 @@
     void addToString(String toString);
 
     /**
-     * Makes the fabricated class implement the provided service interface. The interface will be
-     * added, and all methods in the interface will be delegate wrappers. If toString() is not part
-     * of the delegate interface, then an implementation will be supplied that returns the provided
-     * string. This method is used when creating objects that proxy their behavior to some other
-     * object.
+     * Makes the fabricated class implement the provided service interface. The interface will be added, and all methods
+     * in the interface will be delegate wrappers. If toString() is not part of the delegate interface, then an
+     * implementation will be supplied that returns the provided string. This method is used when creating objects that
+     * proxy their behavior to some other object.
      *
      * @param serviceInterface   the interface to implement
-     * @param delegateExpression the expression used to find the delegate on which methods should be invoked.
-     *                           Typically a field name, such as "_delegate", or a method to invoke, such as
-     *                           "_service()".
+     * @param delegateExpression the expression used to find the delegate on which methods should be invoked. Typically
+     *                           a field name, such as "_delegate", or a method to invoke, such as "_service()".
      * @param toString           fixed value to be returned as the description of the resultant object
      */
     void proxyMethodsToDelegate(Class serviceInterface, String delegateExpression, String toString);
 
     /**
-     * Invoked last to create the class. This will enforce that all abstract methods have been
-     * implemented in the (concrete) class.
+     * Invoked last to create the class. This will enforce that all abstract methods have been implemented in the
+     * (concrete) class.
      */
     Class createClass();
 
     /**
-     * Adds a public no-op method. The method will return null, false, or zero as per the return
-     * type (if not void).
+     * Adds a public no-op method. The method will return null, false, or zero as per the return type (if not void).
      */
 
     void addNoOpMethod(MethodSignature signature);

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFabUtils.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFabUtils.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFactory.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFactory.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.Location;
+import org.apache.tapestry5.ioc.Location;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;
@@ -25,32 +25,30 @@
 public interface ClassFactory
 {
     /**
-     * Simplified version of {@link #newClass(String, Class)} that generates a name based on the
-     * service interface name, extends from java.lang.Object, and automatically adds the
-     * serviceInterface to the returned ClassFab. This is the most common use when creating the
-     * kinds of proxies used throughout Tapestry IoC.
+     * Simplified version of {@link #newClass(String, Class)} that generates a name based on the service interface name,
+     * extends from java.lang.Object, and automatically adds the serviceInterface to the returned ClassFab. This is the
+     * most common use when creating the kinds of proxies used throughout Tapestry IoC.
      *
      * @param serviceInterface
      */
     ClassFab newClass(Class serviceInterface);
 
     /**
-     * Creates a {@link ClassFab} object for the given name; the new class is a subclass of the
-     * indicated class. The new class is always public and concrete.
+     * Creates a {@link ClassFab} object for the given name; the new class is a subclass of the indicated class. The new
+     * class is always public and concrete.
      *
-     * @param name       the full qualified name of the class to create (note that it is common to place
-     *                   created classes in the default package)
+     * @param name       the full qualified name of the class to create (note that it is common to place created classes
+     *                   in the default package)
      * @param superClass the parent class, which is often java.lang.Object
      */
 
     ClassFab newClass(String name, Class superClass);
 
     /**
-     * Imports the class to make it referenceable within the factory. The class loader for the class
-     * is added to the class path. The class itself is returned, if its bytecode is available. If
-     * not, a search up the inhertance occurs until a proper class (that can be referenced in
-     * generated bytecode) is found. This is necessary to handle cases where a class is generated at
-     * runtime, outside of the class factory, and bytecode is not available for it.
+     * Imports the class to make it referenceable within the factory. The class loader for the class is added to the
+     * class path. The class itself is returned, if its bytecode is available. If not, a search up the inhertance occurs
+     * until a proper class (that can be referenced in generated bytecode) is found. This is necessary to handle cases
+     * where a class is generated at runtime, outside of the class factory, and bytecode is not available for it.
      *
      * @param clazz
      * @return a referencable super-class
@@ -64,14 +62,13 @@
     int getCreatedClassCount();
 
     /**
-     * Returns the class loader used when creating new classes; this is generally the same as the
-     * current thread's context class loader (except perhaps during testing).
+     * Returns the class loader used when creating new classes; this is generally the same as the current thread's
+     * context class loader (except perhaps during testing).
      */
     ClassLoader getClassLoader();
 
     /**
-     * Converts a method to a {@link Location}, which includes information about the source
-     * file name and line number.
+     * Converts a method to a {@link Location}, which includes information about the source file name and line number.
      *
      * @param method to look up
      * @return the location, or null if the necessary information is not available
@@ -79,8 +76,8 @@
     Location getMethodLocation(Method method);
 
     /**
-     * Return a string representation fo the constructor (including class and parameters) and (if
-     * available) file name and line number.
+     * Return a string representation fo the constructor (including class and parameters) and (if available) file name
+     * and line number.
      */
     Location getConstructorLocation(Constructor constructor);
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassNameLocator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassNameLocator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassNameLocator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassNameLocator.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 import java.util.Collection;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassPropertyAdapter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassPropertyAdapter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Coercion.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Coercion.java Tue May 20 11:51:35 2008
@@ -1,27 +1,24 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.services;
 
 /**
- * Responsible for converting from one type to another. This is used primarily around component
- * parameters.
+ * Responsible for converting from one type to another. This is used primarily around component parameters.
  *
- * @param <S>
- * the source type (input)
- * @param <T>
- * the target type (output)
+ * @param <S> the source type (input)
+ * @param <T> the target type (output)
  */
 public interface Coercion<S, T>
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/CoercionTuple.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/CoercionTuple.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/DefaultImplementationBuilder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/DefaultImplementationBuilder.java Tue May 20 11:51:35 2008
@@ -1,30 +1,30 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.services;
 
 /**
  * Creates default implementatons of a class.
  *
- * @see org.apache.tapestry.ioc.services.ClassFab#addNoOpMethod(MethodSignature)
+ * @see org.apache.tapestry5.ioc.services.ClassFab#addNoOpMethod(MethodSignature)
  */
 public interface DefaultImplementationBuilder
 {
     /**
-     * Creates a new implementation of the provided interface. Each method in the interface will be
-     * implemented as a noop method. The method will ignore any parameters and return null, or 0, or
-     * false (or return nothing if the method is void).
+     * Creates a new implementation of the provided interface. Each method in the interface will be implemented as a
+     * noop method. The method will ignore any parameters and return null, or 0, or false (or return nothing if the
+     * method is void).
      *
      * @param <S>
      * @param serviceInterface

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionAnalysis.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionAnalysis.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionAnalysis.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionAnalysis.java Tue May 20 11:51:35 2008
@@ -1,18 +1,18 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.services;
 
 import java.util.List;
 
@@ -24,8 +24,7 @@
 public interface ExceptionAnalysis
 {
     /**
-     * Returns the analyzed exception info for each exception. The are ordered outermost exception
-     * to innermost.
+     * Returns the analyzed exception info for each exception. The are ordered outermost exception to innermost.
      */
     List<ExceptionInfo> getExceptionInfos();
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionAnalyzer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionAnalyzer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionAnalyzer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionAnalyzer.java Tue May 20 11:51:35 2008
@@ -1,22 +1,22 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.services;
 
 /**
- * Analyzes an exception, providing an analysis. The analysis easily exposes properties of the
- * exception, the stack trace, and nested exceptions.
+ * Analyzes an exception, providing an analysis. The analysis easily exposes properties of the exception, the stack
+ * trace, and nested exceptions.
  */
 public interface ExceptionAnalyzer
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionInfo.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionInfo.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionInfo.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionInfo.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 import java.util.List;
 
 /**
  * Contains information about an analyzed exception.
  *
- * @see {@link org.apache.tapestry.ioc.services.ExceptionAnalysis}
+ * @see {@link org.apache.tapestry5.ioc.services.ExceptionAnalysis}
  */
 public interface ExceptionInfo
 {
@@ -44,8 +44,7 @@
     Object getProperty(String name);
 
     /**
-     * Returns the stack trace elements. Generally this is an empty list except for the deepest
-     * exception.
+     * Returns the stack trace elements. Generally this is an empty list except for the deepest exception.
      */
     List<StackTraceElement> getStackTrace();
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionTracker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionTracker.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/FactoryDefaults.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/FactoryDefaults.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -22,11 +22,11 @@
 import java.lang.annotation.Target;
 
 /**
- * Used to disambiguate which version of {@link SymbolProvider} is being referenced. Symbols defined
- * by contributing to FactoryDefaults are overridden by contributions to {@link ApplicationDefaults}.
+ * Used to disambiguate which version of {@link SymbolProvider} is being referenced. Symbols defined by contributing to
+ * FactoryDefaults are overridden by contributions to {@link ApplicationDefaults}.
  */
 @Target(
-        {PARAMETER, FIELD})
+        { PARAMETER, FIELD })
 @Retention(RUNTIME)
 @Documented
 public @interface FactoryDefaults

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/LoggingDecorator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/LoggingDecorator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/LoggingDecorator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/LoggingDecorator.java Tue May 20 11:51:35 2008
@@ -1,25 +1,25 @@
-// Copyright 2006, 2007 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006, 2007 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.services;
 
 import org.slf4j.Logger;
 
 /**
- * Service that can create a logging interceptor that wraps around a service implementation (or
- * interceptor). The interceptor works with the service's log to log, at debug level, method entry
- * (with arguments), method exit (with return value, if any) as well as any thrown exceptions.
+ * Service that can create a logging interceptor that wraps around a service implementation (or interceptor). The
+ * interceptor works with the service's log to log, at debug level, method entry (with arguments), method exit (with
+ * return value, if any) as well as any thrown exceptions.
  */
 public interface LoggingDecorator
 {
@@ -31,8 +31,8 @@
      * @param delegate         existing object to be wrapped
      * @param serviceId        id of service
      * @param logger           log used for debug level logging messages by the interceptor
-     * @return a new object implementing the interface that can be used in place of the delegate,
-     *         providing logging behavior around each method call on the service interface
+     * @return a new object implementing the interface that can be used in place of the delegate, providing logging
+     *         behavior around each method call on the service interface
      */
     <T> T build(Class<T> serviceInterface, T delegate, String serviceId, Logger logger);
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MasterObjectProvider.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MasterObjectProvider.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MasterObjectProvider.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MasterObjectProvider.java Tue May 20 11:51:35 2008
@@ -12,32 +12,30 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.AnnotationProvider;
-import org.apache.tapestry.ioc.ObjectLocator;
-import org.apache.tapestry.ioc.ObjectProvider;
+import org.apache.tapestry5.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.ObjectLocator;
+import org.apache.tapestry5.ioc.ObjectProvider;
 
 /**
- * Rolls up a number of {@link ObjectProvider}, but allows for the case where no object may be
- * provided.
+ * Rolls up a number of {@link ObjectProvider}, but allows for the case where no object may be provided.
  */
 public interface MasterObjectProvider
 {
     /**
-     * Provides an object based on an expression. The process of providing objects occurs within a
-     * particular <em>context</em>, which will typically be a service builder method, service
-     * contributor method, or service decorator method. The locator parameter provides access to the
-     * services visible <em>to that context</em>.
+     * Provides an object based on an expression. The process of providing objects occurs within a particular
+     * <em>context</em>, which will typically be a service builder method, service contributor method, or service
+     * decorator method. The locator parameter provides access to the services visible <em>to that context</em>.
      * <p/>
-     * When the value is required and no {@link ObjectProvider} provided a non-null value, then
-     * {@link ObjectLocator#getService(Class)} is invoked, to provide a uniquely matching service,
-     * or throw a failure exception if no <em>single</em> service can be found.
+     * When the value is required and no {@link ObjectProvider} provided a non-null value, then {@link
+     * ObjectLocator#getService(Class)} is invoked, to provide a uniquely matching service, or throw a failure exception
+     * if no <em>single</em> service can be found.
      *
      * @param objectType         the expected object type
      * @param annotationProvider provides access to annotations (typically, the field or parameter to which an
-     *                           injection-related annotation is attached); annotations on the field or parameter
-     *                           may also be used when resolving the desired object
+     *                           injection-related annotation is attached); annotations on the field or parameter may
+     *                           also be used when resolving the desired object
      * @param locator            locator for the <em>context</em> in which the provider is being used
      * @param required           if true (normal case) a value must be provided; if false then it is allowed for no
      *                           ObjectProvider to provide a value, and this method may return null to indicate the

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MethodIterator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MethodIterator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MethodIterator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MethodIterator.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newList;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newMap;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newList;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newMap;
 
 import java.lang.reflect.Method;
 import java.util.*;
@@ -25,7 +25,7 @@
  * some complications that can occur when a class inherits the same method from multiple interfaces and with slightly
  * different signatures (due to the fact that declared thrown exceptions can vary slightly for the "same" method).
  *
- * @see org.apache.tapestry.ioc.services.MethodSignature#isOverridingSignatureOf(MethodSignature)
+ * @see org.apache.tapestry5.ioc.services.MethodSignature#isOverridingSignatureOf(MethodSignature)
  */
 public class MethodIterator
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MethodSignature.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MethodSignature.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PerthreadManager.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PerthreadManager.java Tue May 20 11:51:35 2008
@@ -12,39 +12,36 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 /**
  * Manages per-thread data, and provides a way for listeners to know when such data should be cleaned up.  Typically,
- * data is cleaned up at the end of the request (in a web application).
- * Tapestry IoC has any number of objects that need to know
- * when this event occurs, so that they can clean up any per-thread/per-request state.
+ * data is cleaned up at the end of the request (in a web application). Tapestry IoC has any number of objects that need
+ * to know when this event occurs, so that they can clean up any per-thread/per-request state.
  * <p/>
- * Due to <a href="https://issues.apache.org/jira/browse/TAPESTRY-2141">TAPESTRY-2141<a> (and
- * the underlying JDK 1.5 bug <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=5025230">5025230</a>),
- * this service has expanded to manager per-thread data (not just end-of-request listeners).
+ * Due to <a href="https://issues.apache.org/jira/browse/TAPESTRY-2141">TAPESTRY-2141<a> (and the underlying JDK 1.5 bug
+ * <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=5025230">5025230</a>), this service has expanded to
+ * manager per-thread data (not just end-of-request listeners).
  */
 public interface PerthreadManager
 {
     /**
-     * Adds a listener to the hub.  All listeners are discarded at the
-     * {@link #cleanup()}.
+     * Adds a listener to the hub.  All listeners are discarded at the {@link #cleanup()}.
      *
      * @param listener to add
      */
     void addThreadCleanupListener(ThreadCleanupListener listener);
 
     /**
-     * Immediately performs a cleanup of the thread, notifying all listeners then
-     * discarding the thread locale and the map it stores.
+     * Immediately performs a cleanup of the thread, notifying all listeners then discarding the thread locale and the
+     * map it stores.
      */
     void cleanup();
 
 
     /**
-     * Returns an object stored in the per-thread map.    When the object is a string,
-     * the expected name is <em>service id</em>.<em>subkey</em>.  Unlike most of Tapestry,
-     * such keys <em>will</em> be case sensitive.
+     * Returns an object stored in the per-thread map.    When the object is a string, the expected name is <em>service
+     * id</em>.<em>subkey</em>.  Unlike most of Tapestry, such keys <em>will</em> be case sensitive.
      *
      * @param key key used to retrieve object
      * @return corresponding per-thread object, or null
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/DependencyNode.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/DependencyNode.java Tue May 20 11:51:35 2008
@@ -12,17 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
-import org.apache.tapestry.ioc.Orderable;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newList;
+import org.apache.tapestry5.ioc.Orderable;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newList;
 import org.slf4j.Logger;
 
 import java.util.List;
 
 /**
  * Used by {@link org.apache.tapestry.ioc.internal.util.Orderer} to establish backward dependencies for {@link
  * org.apache.tapestry.ioc.Orderable} objects.
  *
  * @param <T>
  */
@@ -134,4 +134,4 @@
         list.add(orderable);
     }
 
-}
\ No newline at end of file
+}
@@ -12,17 +12,17 @@
 
 /**
- * Used by {@link org.apache.tapestry.ioc.internal.util.Orderer} to establish backward dependencies for {@link
- * org.apache.tapestry.ioc.Orderable} objects.
+ * Used by {@link org.apache.tapestry5.ioc.internal.util.Orderer} to establish backward dependencies for {@link
+ * org.apache.tapestry5.ioc.Orderable} objects.
  *
  * @param <T>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/GenericsUtils.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/GenericsUtils.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/InternalUtils.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/InternalUtils.java Tue May 20 11:51:35 2008
@@ -12,17 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
-import org.apache.tapestry.ioc.AnnotationProvider;
-import org.apache.tapestry.ioc.Locatable;
-import org.apache.tapestry.ioc.Location;
-import org.apache.tapestry.ioc.ObjectLocator;
-import org.apache.tapestry.ioc.annotation.Inject;
-import org.apache.tapestry.ioc.annotation.InjectService;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newList;
-import static org.apache.tapestry.ioc.internal.util.Defense.notBlank;
-import org.apache.tapestry.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.Locatable;
+import org.apache.tapestry5.ioc.Location;
+import org.apache.tapestry5.ioc.ObjectLocator;
+import org.apache.tapestry5.ioc.annotations.Inject;
+import org.apache.tapestry5.ioc.annotations.InjectService;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newList;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notBlank;
+import org.apache.tapestry5.ioc.services.ClassFactory;
 
 import java.io.Closeable;
 import java.io.IOException;
@@ -450,7 +450,7 @@
      * Searches a class for the "best" constructor, the public constructor with the most parameters. Returns null if
      * there are no public constructors. If there is more than one constructor with the maximum number of parameters, it
      * is not determined which will be returned (don't build a class like that!). In addition, if a constructor is
      * annotated with {@link org.apache.tapestry.ioc.annotation.Inject}, it will be used (no check for multiple such
      * constructors is made, only at most a single constructor should have the annotation).
      *
      * @param clazz to search for a constructor for
@@ -450,7 +450,7 @@
      * there are no public constructors. If there is more than one constructor with the maximum number of parameters, it
      * is not determined which will be returned (don't build a class like that!). In addition, if a constructor is
-     * annotated with {@link org.apache.tapestry.ioc.annotation.Inject}, it will be used (no check for multiple such
+     * annotated with {@link org.apache.tapestry5.ioc.annotations.Inject}, it will be used (no check for multiple such
      * constructors is made, only at most a single constructor should have the annotation).
      *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Invokable.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/Invokable.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/LocationImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/LocationImpl.java Tue May 20 11:51:35 2008
@@ -12,15 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
-import org.apache.tapestry.ioc.Location;
-import org.apache.tapestry.ioc.Resource;
+import org.apache.tapestry5.ioc.Location;
+import org.apache.tapestry5.ioc.Resource;
 
 import java.util.Formatter;
 
 /**
  * Implementation class for {@link org.apache.tapestry.ioc.Location}.
  */
 public final class LocationImpl implements Location
 {
@@ -12,15 +12,15 @@
 
 /**
- * Implementation class for {@link org.apache.tapestry.ioc.Location}.
+ * Implementation class for {@link org.apache.tapestry5.ioc.Location}.
  */
 public final class LocationImpl implements Location

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/MessageFormatterImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/MessageFormatterImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/MessagesImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/MessagesImpl.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.internal.util;
+package org.apache.tapestry5.ioc.internal.util;
 
-import org.apache.tapestry.ioc.Messages;
-import org.apache.tapestry.ioc.util.AbstractMessages;
+import org.apache.tapestry5.ioc.Messages;
+import org.apache.tapestry5.ioc.util.AbstractMessages;
 
 import java.util.Enumeration;
 import java.util.Locale;
@@ -23,7 +23,7 @@
 import java.util.ResourceBundle;
 
 /**
  * Implementation of {@link org.apache.tapestry.ioc.Messages} based around a {@link java.util.ResourceBundle}.
  */
 public class MessagesImpl extends AbstractMessages
 {
@@ -23,7 +23,7 @@
 
 /**
- * Implementation of {@link org.apache.tapestry.ioc.Messages} based around a {@link java.util.ResourceBundle}.
+ * Implementation of {@link org.apache.tapestry5.ioc.Messages} based around a {@link java.util.ResourceBundle}.
  */
 public class MessagesImpl extends AbstractMessages

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/OneShotLock.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/internal/util/OneShotLock.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/AspectDecorator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/AspectDecorator.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.MethodAdvice;
+import org.apache.tapestry5.ioc.MethodAdvice;
 
 
 /**
  * A decorator used to create an interceptor that delegates each method's invocation to an {@link
  * org.apache.tapestry.ioc.MethodAdvice} for advice.  Advice can inspect or change method parameters, inspect or change
  * the method's return value, and inspect and change thrown exceptions (checked and unchecked).
  */
 public interface AspectDecorator
@@ -12,14 +12,14 @@
 /**
  * A decorator used to create an interceptor that delegates each method's invocation to an {@link
- * org.apache.tapestry.ioc.MethodAdvice} for advice.  Advice can inspect or change method parameters, inspect or change
+ * org.apache.tapestry5.ioc.MethodAdvice} for advice.  Advice can inspect or change method parameters, inspect or change
  * the method's return value, and inspect and change thrown exceptions (checked and unchecked).
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/AspectInterceptorBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/AspectInterceptorBuilder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/AspectInterceptorBuilder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/AspectInterceptorBuilder.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.MethodAdvice;
+import org.apache.tapestry5.ioc.MethodAdvice;
 
 import java.lang.reflect.Method;
 
 /**
  * A builder may be obtained from the {@link org.apache.tapestry.ioc.services.AspectDecorator} and allows more
  * controlled creation of the created interceptor; it allows different methods to be given different advice, and allows
  * methods to be omitted (in which case the method invocation passes through without advice).
  */
@@ -12,14 +12,14 @@
 
 /**
- * A builder may be obtained from the {@link org.apache.tapestry.ioc.services.AspectDecorator} and allows more
+ * A builder may be obtained from the {@link org.apache.tapestry5.ioc.services.AspectDecorator} and allows more
  * controlled creation of the created interceptor; it allows different methods to be given different advice, and allows
  * methods to be omitted (in which case the method invocation passes through without advice).

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Builtin.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Builtin.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFabUtils.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFabUtils.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import org.apache.tapestry.ioc.ObjectCreator;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newMap;
+import org.apache.tapestry5.ioc.ObjectCreator;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newMap;
 
 import static java.lang.String.format;
 import java.lang.reflect.Method;
@@ -24,7 +24,7 @@
 import java.util.concurrent.atomic.AtomicLong;
 
 /**
  * Handy method useful when creating new classes using {@link org.apache.tapestry.ioc.services.ClassFab}.
  */
 public final class ClassFabUtils
 {
@@ -228,7 +228,7 @@
     }
 
     /**
      * Creates a proxy for a given service interface around an {@link org.apache.tapestry.ioc.ObjectCreator} that can
      * provide (on demand) an object (implementing the service interface) to delegate to. The ObjectCreator will be
      * invoked on every method invocation (if it is caching, that should be internal to its implementation).
      *
@@ -268,4 +268,4 @@
             throw new RuntimeException(ex.getMessage(), ex);
         }
     }
-}
\ No newline at end of file
+}
@@ -24,7 +24,7 @@
 
 /**
- * Handy method useful when creating new classes using {@link org.apache.tapestry.ioc.services.ClassFab}.
+ * Handy method useful when creating new classes using {@link org.apache.tapestry5.ioc.services.ClassFab}.
  */
 public final class ClassFabUtils
@@ -228,7 +228,7 @@
 
     /**
-     * Creates a proxy for a given service interface around an {@link org.apache.tapestry.ioc.ObjectCreator} that can
+     * Creates a proxy for a given service interface around an {@link org.apache.tapestry5.ioc.ObjectCreator} that can
      * provide (on demand) an object (implementing the service interface) to delegate to. The ObjectCreator will be
      * invoked on every method invocation (if it is caching, that should be internal to its implementation).

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFactory.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassFactory.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassPropertyAdapter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ClassPropertyAdapter.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
 import java.util.List;
 
 /**
  * Organizes all {@link org.apache.tapestry.ioc.services.PropertyAdapter}s for a particular class.
  * <p/>
  * Only provides access to <em>simple</em> properties. Indexed properties are ignored.
  * <p/>
@@ -12,12 +12,12 @@
 
 /**
- * Organizes all {@link org.apache.tapestry.ioc.services.PropertyAdapter}s for a particular class.
+ * Organizes all {@link org.apache.tapestry5.ioc.services.PropertyAdapter}s for a particular class.
  * <p/>
  * Only provides access to <em>simple</em> properties. Indexed properties are ignored.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Coercion.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/Coercion.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/CoercionTuple.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/CoercionTuple.java Tue May 20 11:51:35 2008
@@ -12,15 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import static org.apache.tapestry.ioc.internal.util.Defense.notNull;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notNull;
 
 /**
  * An immutable object that represents a mapping from one type to another. This is also the contribution type when
  * building the {@link org.apache.tapestry.ioc.services.TypeCoercer} service. Wraps a {@link
  * org.apache.tapestry.ioc.services.Coercion} object that performs the work with additional properties that describe the
  * input and output types of the coercion, needed when searching for an appropriate coercion (or sequence of
  * coercions).
  *
  * @param <S> source (input) type
@@ -12,15 +12,15 @@
 /**
  * An immutable object that represents a mapping from one type to another. This is also the contribution type when
- * building the {@link org.apache.tapestry.ioc.services.TypeCoercer} service. Wraps a {@link
- * org.apache.tapestry.ioc.services.Coercion} object that performs the work with additional properties that describe the
- * input and output types of the coercion, needed when searching for an appropriate coercion (or sequence of
+ * building the {@link org.apache.tapestry5.ioc.services.TypeCoercer} service. Wraps a {@link
+ * org.apache.tapestry5.ioc.services.Coercion} object that performs the work with additional properties that describe
+ * the input and output types of the coercion, needed when searching for an appropriate coercion (or sequence of
  * coercions).
  *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/DefaultImplementationBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/DefaultImplementationBuilder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionTracker.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/ExceptionTracker.java Tue May 20 11:51:35 2008
@@ -1,30 +1,29 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc.services;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc.services;
 
 /**
  * Used by {@link org.apache.tapestry.ioc.services.LoggingDecorator} to track which exceptions have
  * been logged during the current request (the ExceptionTracker is perthread). This keeps redundant
  * information from appearing in the console output.
  */
 public interface ExceptionTracker
 {
     /**
-     * Returns true if the indicated exception has already been logged (it is assumed that the
-     * exception will be logged if this method returns false). The exception is recorded for later
-     * checks.
+     * Returns true if the indicated exception has already been logged (it is assumed that the exception will be logged
+     * if this method returns false). The exception is recorded for later checks.
      *
      * @param exception to check
      * @return false if the exception has not been previously checked, true otherwise
@@ -1,30 +1,29 @@
 
 /**
- * Used by {@link org.apache.tapestry.ioc.services.LoggingDecorator} to track which exceptions have
- * been logged during the current request (the ExceptionTracker is perthread). This keeps redundant
- * information from appearing in the console output.
+ * Used by {@link org.apache.tapestry5.ioc.services.LoggingDecorator} to track which exceptions have been logged during
+ * the current request (the ExceptionTracker is perthread). This keeps redundant information from appearing in the
+ * console output.
  */
 public interface ExceptionTracker

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/FactoryDefaults.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/FactoryDefaults.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MethodSignature.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/MethodSignature.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.services;
+package org.apache.tapestry5.ioc.services;
 
-import static org.apache.tapestry.ioc.internal.util.Defense.notBlank;
-import static org.apache.tapestry.ioc.internal.util.Defense.notNull;
-import static org.apache.tapestry.ioc.internal.util.InternalUtils.size;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notBlank;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notNull;
+import static org.apache.tapestry5.ioc.internal.util.InternalUtils.size;
 
 import java.lang.reflect.Method;
 import java.util.Arrays;
@@ -31,7 +31,7 @@
  * instance and static methods</em>.
  * <p/>
  * This version of MethodSignature works with <em>loaded</em> classes, and it usually used in the context of {@link
  * org.apache.tapestry.ioc.services.ClassFab} to create new classes and subclasses.
  */
 public class MethodSignature
 {
@@ -31,7 +31,7 @@
  * <p/>
  * This version of MethodSignature works with <em>loaded</em> classes, and it usually used in the context of {@link
- * org.apache.tapestry.ioc.services.ClassFab} to create new classes and subclasses.
+ * org.apache.tapestry5.ioc.services.ClassFab} to create new classes and subclasses.
  */
 public class MethodSignature

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PerthreadManager.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/services/PerthreadManager.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================